==> libdatetime-locale-perl_1.33.orig.tar.gz: DateTime-Locale-1.33/share/doi.pl <==
{
  am_pm_abbreviated => [
    "\N{U+0938}\N{U+0935}\N{U+0947}\N{U+0930}",
    "\N{U+0938}\N{U+2019}\N{U+091e}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "E, d, MMM G y",
    GyMMMd => "d, MMM G y",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "MMMM \N{U+0926}\N{U+093e} \N{U+0939}\N{U+092b}\N{U+094d}\N{U+0924}\N{U+093e} W",
    "MMMMW-count-other" => "MMMM \N{U+0926}\N{U+093e} \N{U+0939}\N{U+092b}\N{U+094d}\N{U+0924}\N{U+093e} W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d, MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d, MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "Y \N{U+0926}\N{U+093e} \N{U+0939}\N{U+092b}\N{U+094d}\N{U+0924}\N{U+093e} w",
    "yw-count-other" => "Y \N{U+0926}\N{U+093e} \N{U+0939}\N{U+092b}\N{U+094d}\N{U+0924}\N{U+093e} w",
  },
  code => "doi",
  date_format_full => "EEEE, d, MMMM y",
  date_format_long => "d, MMMM y",
  date_format_medium => "d, MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} \N{U+0917}\N{U+0940} {0}",
  datetime_format_long => "{1} \N{U+0917}\N{U+0940} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0938}\N{U+094b}\N{U+092e}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}",
    "\N{U+092c}\N{U+0941}\N{U+0927}",
    "\N{U+092c}\N{U+0940}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}",
    "\N{U+0936}\N{U+0928}\N{U+093f}",
    "\N{U+0910}\N{U+0924}",
  ],
  day_format_narrow => [
    "\N{U+0938}\N{U+094b}.",
    "\N{U+092e}.",
    "\N{U+092c}\N{U+0941}.",
    "\N{U+092c}\N{U+0940}.",
    "\N{U+0936}\N{U+0941}.",
    "\N{U+0936}.",
    "\N{U+0910}.",
  ],
  day_format_wide => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0940}\N{U+0930}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0928}\N{U+0940}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0910}\N{U+0924}\N{U+092c}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0938}\N{U+094b}\N{U+092e}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}",
    "\N{U+092c}\N{U+0941}\N{U+0927}",
    "\N{U+092c}\N{U+0940}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}",
    "\N{U+0936}\N{U+0928}\N{U+093f}",
    "\N{U+0910}\N{U+0924}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0938}\N{U+094b}",
    "\N{U+092e}.",
    "\N{U+092c}\N{U+0941}.",
    "\N{U+092c}\N{U+0940}.",
    "\N{U+0936}\N{U+0941}.",
    "\N{U+0936}.",
    "\N{U+0910}",
  ],
  day_stand_alone_wide => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0940}\N{U+0930}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0928}\N{U+093f}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0910}\N{U+0924}\N{U+092c}\N{U+093e}\N{U+0930}",
  ],
  era_abbreviated => [
    "\N{U+0908}.\N{U+092a}\N{U+0942}.",
    "\N{U+0908}\N{U+0938}\N{U+0935}\N{U+0940}",
  ],
  era_narrow => [
    "\N{U+0908}.\N{U+092a}\N{U+0942}.",
    "\N{U+0908}\N{U+0938}\N{U+0935}\N{U+0940}",
  ],
  era_wide => [
    "\N{U+0908}.\N{U+092a}\N{U+0942}.",
    "\N{U+0908}. \N{U+0938}\N{U+0928}\N{U+094d}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Dogri",
  month_format_abbreviated => [
    "\N{U+091c}\N{U+0928}.",
    "\N{U+092b}\N{U+0930}.",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}.",
    "\N{U+0938}\N{U+093f}\N{U+0924}.",
    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}.",
    "\N{U+0928}\N{U+0935}.",
    "\N{U+0926}\N{U+093f}\N{U+0938}.",
  ],
  month_format_narrow => [
    "\N{U+091c}",
    "\N{U+092b}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+0905}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}",
    "\N{U+0938}\N{U+093f}",
    "\N{U+0905}",
    "\N{U+0928}",
    "\N{U+0926}\N{U+093f}",
  ],
  month_format_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+093f}\N{U+0924}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0924}\N{U+094d}\N{U+0924}\N{U+0942}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+093f}\N{U+0938}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+091c}\N{U+0928}.",
    "\N{U+092b}\N{U+0930}.",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}.",
    "\N{U+0938}\N{U+093f}\N{U+0924}.",
    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}.",
    "\N{U+0928}\N{U+0935}.",
    "\N{U+0926}\N{U+093f}\N{U+0938}.",
  ],
  month_stand_alone_narrow => [
    "\N{U+091c}",
    "\N{U+092b}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+0905}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}",
    "\N{U+0938}\N{U+093f}",
    "\N{U+0905}",
    "\N{U+0928}",
    "\N{U+0926}\N{U+093f}",
  ],
  month_stand_alone_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+093f}\N{U+0924}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+093f}\N{U+0938}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  name => "Dogri",
  native_language => "\N{U+0921}\N{U+094b}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_name => "\N{U+0921}\N{U+094b}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0924}\N{U+094d}\N{U+0930}.1",
    "\N{U+0924}\N{U+094d}\N{U+0930}.2",
    "\N{U+0924}\N{U+094d}\N{U+0930}.3",
    "\N{U+0924}\N{U+094d}\N{U+0930}.4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+092a}\N{U+0948}\N{U+0939}\N{U+0932}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+0926}\N{U+0942}\N{U+0908} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+0924}\N{U+094d}\N{U+0930}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094c}\N{U+0925}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0924}\N{U+094d}\N{U+0930}.1",
    "\N{U+0924}\N{U+094d}\N{U+0930}.2",
    "\N{U+0924}\N{U+094d}\N{U+0930}.3",
    "\N{U+0924}\N{U+094d}\N{U+0930}.4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+092a}\N{U+0948}\N{U+0939}\N{U+0932}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+0926}\N{U+0942}\N{U+0908} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+0924}\N{U+094d}\N{U+0930}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094c}\N{U+0925}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 40,
}

==> libdatetime-locale-perl_1.37.orig.tar.gz: DateTime-Locale-1.37/share/doi.pl <==
{
  am_pm_abbreviated => [
    "\N{U+0938}\N{U+0935}\N{U+0947}\N{U+0930}",
    "\N{U+0938}\N{U+2019}\N{U+091e}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "E, d, MMM G y",
    GyMMMd => "d, MMM G y",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "MMMM \N{U+0926}\N{U+093e} \N{U+0939}\N{U+092b}\N{U+094d}\N{U+0924}\N{U+093e} W",
    "MMMMW-count-other" => "MMMM \N{U+0926}\N{U+093e} \N{U+0939}\N{U+092b}\N{U+094d}\N{U+0924}\N{U+093e} W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d, MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d, MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "Y \N{U+0926}\N{U+093e} \N{U+0939}\N{U+092b}\N{U+094d}\N{U+0924}\N{U+093e} w",
    "yw-count-other" => "Y \N{U+0926}\N{U+093e} \N{U+0939}\N{U+092b}\N{U+094d}\N{U+0924}\N{U+093e} w",
  },
  code => "doi",
  date_format_full => "EEEE, d, MMMM y",
  date_format_long => "d, MMMM y",
  date_format_medium => "d, MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0938}\N{U+094b}\N{U+092e}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}",
    "\N{U+092c}\N{U+0941}\N{U+0927}",
    "\N{U+092c}\N{U+0940}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}",
    "\N{U+0936}\N{U+0928}\N{U+093f}",
    "\N{U+0910}\N{U+0924}",
  ],
  day_format_narrow => [
    "\N{U+0938}\N{U+094b}.",
    "\N{U+092e}.",
    "\N{U+092c}\N{U+0941}.",
    "\N{U+092c}\N{U+0940}.",
    "\N{U+0936}\N{U+0941}.",
    "\N{U+0936}.",
    "\N{U+0910}.",
  ],
  day_format_wide => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0940}\N{U+0930}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0928}\N{U+093f}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0910}\N{U+0924}\N{U+092c}\N{U+093e}\N{U+0930}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0938}\N{U+094b}\N{U+092e}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}",
    "\N{U+092c}\N{U+0941}\N{U+0927}",
    "\N{U+092c}\N{U+0940}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}",
    "\N{U+0936}\N{U+0928}\N{U+093f}",
    "\N{U+0910}\N{U+0924}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0938}\N{U+094b}",
    "\N{U+092e}.",
    "\N{U+092c}\N{U+0941}.",
    "\N{U+092c}\N{U+0940}.",
    "\N{U+0936}\N{U+0941}.",
    "\N{U+0936}.",
    "\N{U+0910}",
  ],
  day_stand_alone_wide => [
    "\N{U+0938}\N{U+094b}\N{U+092e}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+0932}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0941}\N{U+0927}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+092c}\N{U+0940}\N{U+0930}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0941}\N{U+0915}\N{U+094d}\N{U+0930}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0936}\N{U+0928}\N{U+093f}\N{U+092c}\N{U+093e}\N{U+0930}",
    "\N{U+0910}\N{U+0924}\N{U+092c}\N{U+093e}\N{U+0930}",
  ],
  era_abbreviated => [
    "\N{U+0908}.\N{U+092a}\N{U+0942}.",
    "\N{U+0908}\N{U+0938}\N{U+0935}\N{U+0940}",
  ],
  era_narrow => [
    "\N{U+0908}.\N{U+092a}\N{U+0942}.",
    "\N{U+0908}\N{U+0938}\N{U+0935}\N{U+0940}",
  ],
  era_wide => [
    "\N{U+0908}.\N{U+092a}\N{U+0942}.",
    "\N{U+0908}. \N{U+0938}\N{U+0928}\N{U+094d}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Dogri",
  month_format_abbreviated => [
    "\N{U+091c}\N{U+0928}.",
    "\N{U+092b}\N{U+0930}.",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}.",
    "\N{U+0938}\N{U+093f}\N{U+0924}.",
    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}.",
    "\N{U+0928}\N{U+0935}.",
    "\N{U+0926}\N{U+093f}\N{U+0938}.",
  ],
  month_format_narrow => [
    "\N{U+091c}",
    "\N{U+092b}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+0905}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}",
    "\N{U+0938}\N{U+093f}",
    "\N{U+0905}",
    "\N{U+0928}",
    "\N{U+0926}\N{U+093f}",
  ],
  month_format_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+093f}\N{U+0924}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+093f}\N{U+0938}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+091c}\N{U+0928}.",
    "\N{U+092b}\N{U+0930}.",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}.",
    "\N{U+0938}\N{U+093f}\N{U+0924}.",
    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}.",
    "\N{U+0928}\N{U+0935}.",
    "\N{U+0926}\N{U+093f}\N{U+0938}.",
  ],
  month_stand_alone_narrow => [
    "\N{U+091c}",
    "\N{U+092b}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+0905}",
    "\N{U+092e}\N{U+0947}",
    "\N{U+091c}\N{U+0942}",
    "\N{U+091c}\N{U+0941}",
    "\N{U+0905}",
    "\N{U+0938}\N{U+093f}",
    "\N{U+0905}",
    "\N{U+0928}",
    "\N{U+0926}\N{U+093f}",
  ],
  month_stand_alone_wide => [
    "\N{U+091c}\N{U+0928}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092b}\N{U+0930}\N{U+0935}\N{U+0930}\N{U+0940}",
    "\N{U+092e}\N{U+093e}\N{U+0930}\N{U+094d}\N{U+091a}",
    "\N{U+0905}\N{U+092a}\N{U+094d}\N{U+0930}\N{U+0948}\N{U+0932}",
    "\N{U+092e}\N{U+0947}\N{U+0908}",
    "\N{U+091c}\N{U+0942}\N{U+0928}",
    "\N{U+091c}\N{U+0941}\N{U+0932}\N{U+093e}\N{U+0908}",
    "\N{U+0905}\N{U+0917}\N{U+0938}\N{U+094d}\N{U+0924}",
    "\N{U+0938}\N{U+093f}\N{U+0924}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0905}\N{U+0915}\N{U+094d}\N{U+0924}\N{U+0942}\N{U+092c}\N{U+0930}",
    "\N{U+0928}\N{U+0935}\N{U+0902}\N{U+092c}\N{U+0930}",
    "\N{U+0926}\N{U+093f}\N{U+0938}\N{U+0902}\N{U+092c}\N{U+0930}",
  ],
  name => "Dogri",
  native_language => "\N{U+0921}\N{U+094b}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_name => "\N{U+0921}\N{U+094b}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0924}\N{U+094d}\N{U+0930}.1",
    "\N{U+0924}\N{U+094d}\N{U+0930}.2",
    "\N{U+0924}\N{U+094d}\N{U+0930}.3",
    "\N{U+0924}\N{U+094d}\N{U+0930}.4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+092a}\N{U+0948}\N{U+0939}\N{U+0932}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+0926}\N{U+0942}\N{U+0908} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+0924}\N{U+094d}\N{U+0930}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094c}\N{U+0925}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0924}\N{U+094d}\N{U+0930}.1",
    "\N{U+0924}\N{U+094d}\N{U+0930}.2",
    "\N{U+0924}\N{U+094d}\N{U+0930}.3",
    "\N{U+0924}\N{U+094d}\N{U+0930}.4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+092a}\N{U+0948}\N{U+0939}\N{U+0932}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+0926}\N{U+0942}\N{U+0908} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+0924}\N{U+094d}\N{U+0930}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
    "\N{U+091a}\N{U+094c}\N{U+0925}\N{U+0940} \N{U+0924}\N{U+094d}\N{U+0930}\N{U+092e}\N{U+093e}\N{U+0939}\N{U+0940}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 42,
}
